]> sigrok.org Git - libsigrok.git/blobdiff - std.c
Create & use new sr_usbtmc_dev_inst for Rigol DS driver.
[libsigrok.git] / std.c
diff --git a/std.c b/std.c
index cfe031d993b5e7071e4066bd35c6c091091ff0a1..d1ff84e037c29cdb70044ac68d36c33be1ee7328 100644 (file)
--- a/std.c
+++ b/std.c
@@ -25,7 +25,7 @@
 /**
  * Standard sr_driver_init() API helper.
  *
- * This function can be used to simplify most driver's hw_init() API callback.
+ * This function can be used to simplify most driver's init() API callback.
  *
  * It creates a new 'struct drv_context' (drvc), assigns sr_ctx to it, and
  * then 'drvc' is assigned to the 'struct sr_dev_driver' (di) that is passed.
@@ -37,8 +37,8 @@
  * @return SR_OK upon success, SR_ERR_ARG upon invalid arguments, or
  *         SR_ERR_MALLOC upon memory allocation errors.
  */
-SR_PRIV int std_hw_init(struct sr_context *sr_ctx, struct sr_dev_driver *di,
-                       const char *prefix)
+SR_PRIV int std_init(struct sr_context *sr_ctx, struct sr_dev_driver *di,
+                    const char *prefix)
 {
        struct drv_context *drvc;
 
@@ -63,7 +63,7 @@ SR_PRIV int std_hw_init(struct sr_context *sr_ctx, struct sr_dev_driver *di,
  * Standard API helper for sending an SR_DF_HEADER packet.
  *
  * This function can be used to simplify most driver's
- * hw_dev_acquisition_start() API callback.
+ * dev_acquisition_start() API callback.
  *
  * @param sdi The device instance to use.
  * @param prefix A driver-specific prefix string used for log messages.
@@ -101,27 +101,31 @@ SR_PRIV int std_session_send_df_header(const struct sr_dev_inst *sdi,
        return SR_OK;
 }
 
+#ifdef HAVE_LIBSERIALPORT
+
 /*
  * Standard sr_session_stop() API helper.
  *
  * This function can be used to simplify most (serial port based) driver's
- * hw_dev_acquisition_stop() API callback.
+ * dev_acquisition_stop() API callback.
  *
  * @param sdi The device instance for which acquisition should stop.
  *            Must not be NULL.
  * @param cb_data Opaque 'cb_data' pointer. Must not be NULL.
* @param hw_dev_close_fn Function pointer to the driver's hw_dev_close().
  *                       Must not be NULL.
  * @param serial The serial device instance (struct serial_dev_inst *).
  *               Must not be NULL.
  * @param prefix A driver-specific prefix string used for log messages.
  *               Must not be NULL. An empty string is allowed.
  *
* @return SR_OK upon success, SR_ERR_ARG upon invalid arguments, or
*         SR_ERR upon other errors.
  */
-SR_PRIV int std_hw_dev_acquisition_stop_serial(struct sr_dev_inst *sdi,
-                       void *cb_data, dev_close_t hw_dev_close_fn,
+SR_PRIV int std_dev_acquisition_stop_serial(struct sr_dev_inst *sdi,
+                       void *cb_data, dev_close_t dev_close_fn,
                        struct sr_serial_dev_inst *serial, const char *prefix)
 {
        int ret;
@@ -134,7 +138,7 @@ SR_PRIV int std_hw_dev_acquisition_stop_serial(struct sr_dev_inst *sdi,
 
        if (sdi->status != SR_ST_ACTIVE) {
                sr_err("%sDevice inactive, can't stop acquisition.", prefix);
-               return SR_ERR;
+               return SR_ERR_DEV_CLOSED;
        }
 
        sr_dbg("%sStopping acquisition.", prefix);
@@ -144,7 +148,7 @@ SR_PRIV int std_hw_dev_acquisition_stop_serial(struct sr_dev_inst *sdi,
                return ret;
        }
 
-       if ((ret = hw_dev_close_fn(sdi)) < 0) {
+       if ((ret = dev_close_fn(sdi)) < 0) {
                sr_err("%sFailed to close device: %d.", prefix, ret);
                return ret;
        }
@@ -161,6 +165,8 @@ SR_PRIV int std_hw_dev_acquisition_stop_serial(struct sr_dev_inst *sdi,
        return SR_OK;
 }
 
+#endif
+
 /*
  * Standard driver dev_clear() helper.
  *
@@ -172,15 +178,18 @@ SR_PRIV int std_hw_dev_acquisition_stop_serial(struct sr_dev_inst *sdi,
  * there cannot be freed.
  *
  * @param driver The driver which will have its instances released.
+ * @param clear_private If not NULL, this points to a function called
+ * with sdi->priv as argument. The function can then clear any device
+ * instance-specific resources kept there. It must also clear the struct
+ * pointed to by sdi->priv.
  *
  * @return SR_OK on success.
  */
 SR_PRIV int std_dev_clear(const struct sr_dev_driver *driver,
                std_dev_clear_t clear_private)
 {
-       struct sr_dev_inst *sdi;
        struct drv_context *drvc;
-       struct dev_context *devc;
+       struct sr_dev_inst *sdi;
        GSList *l;
        int ret;
 
@@ -190,31 +199,29 @@ SR_PRIV int std_dev_clear(const struct sr_dev_driver *driver,
 
        ret = SR_OK;
        for (l = drvc->instances; l; l = l->next) {
-               /* Log errors, but continue cleaning up the rest. */
                if (!(sdi = l->data)) {
                        ret = SR_ERR_BUG;
                        continue;
                }
-               if (!(devc = sdi->priv)) {
-                       ret = SR_ERR_BUG;
-                       continue;
-               }
                if (driver->dev_close)
                        driver->dev_close(sdi);
 
                if (sdi->conn) {
-                       if (sdi->inst_type == SR_INST_USB)
+#if HAVE_LIBSERIALPORT
+                       if (sdi->inst_type == SR_INST_SERIAL)
+                               sr_serial_dev_inst_free(sdi->conn);
+#endif
 #if HAVE_LIBUSB_1_0
+                       if (sdi->inst_type == SR_INST_USB)
                                sr_usb_dev_inst_free(sdi->conn);
-#else
-                               ;
 #endif
-                       else if (sdi->inst_type == SR_INST_SERIAL)
-                               sr_serial_dev_inst_free(sdi->conn);
+                       if (sdi->inst_type == SR_INST_USBTMC)
+                               sr_usbtmc_dev_inst_free(sdi->conn);
                }
                if (clear_private)
                        clear_private(sdi->priv);
-               sdi = l->data;
+               else
+                       g_free(sdi->priv);
                sr_dev_inst_free(sdi);
        }
@@ -101,27 +101,31 @@ SR_PRIV int std_session_send_df_header(const struct sr_dev_inst *sdi,
  *            Must not be NULL.
  * @param cb_data Opaque 'cb_data' pointer. Must not be NULL.
- * @param hw_dev_close_fn Function pointer to the driver's hw_dev_close().
+ * @param dev_close_fn Function pointer to the driver's dev_close().
  *                       Must not be NULL.
  * @param serial The serial device instance (struct serial_dev_inst *).
@@ -101,27 +101,31 @@ SR_PRIV int std_session_send_df_header(const struct sr_dev_inst *sdi,
  *               Must not be NULL. An empty string is allowed.
  *
- * @return SR_OK upon success, SR_ERR_ARG upon invalid arguments, or
- *         SR_ERR upon other errors.
+ * @retval SR_OK Success.
+ * @retval SR_ERR_ARG Invalid arguments.
+ * @retval SR_ERR_DEV_CLOSED Device is closed.
+ * @retval SR_ERR Other errors.
  */